@@ -293,7 +293,7 @@ Request example
         code = f'''curl {scheme}://{host}{self.path} \\
 --header "Content-Type: {consumes}" \\
 --request {verb.upper()} \\
---data @- &lt;&lt;'EOF'
+--data @- <<'EOF'
 {data}
 EOF
 '''
